==> biostime-openapi-sdk-1.2.1.RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/hcm/HcmGetUserListResBean.java <==
package global.hh.openapi.sdk.api.bean.hcm;


/**
 * @description: 用户详细信息
 * @author: 777771
 * @date: 2023-27-27 14:27:39
 */
public class HcmGetUserListResBean {

        /**
         * 人员信息对象
         */
        private Object[] userList;

        /**
         * 当前页
         */
        private Number page;

        /**
         * 每页条数
         */
        private Number pageSize;

        /**
         * 总条数
         */
        private Number total;

        /**
         * 总页数
         */
        private Number totalPage;

    public HcmGetUserListResBean(){
    }

    public HcmGetUserListResBean(Object[] userList,Number page,Number pageSize,Number total,Number totalPage){
        this.userList=userList;
        this.page=page;
        this.pageSize=pageSize;
        this.total=total;
        this.totalPage=totalPage;
    }

    private Object[] getUserList() {
        return userList;
    }

    private void setUserList(Object[] userList) {
        this.userList = userList;
    }
    private Number getPage() {
        return page;
    }

    private void setPage(Number page) {
        this.page = page;
    }
    private Number getPageSize() {
        return pageSize;
    }

    private void setPageSize(Number pageSize) {
        this.pageSize = pageSize;
    }
    private Number getTotal() {
        return total;
    }

    private void setTotal(Number total) {
        this.total = total;
    }
    private Number getTotalPage() {
        return totalPage;
    }

    private void setTotalPage(Number totalPage) {
        this.totalPage = totalPage;
    }
}

==> biostime-openapi-sdk-1.5.9.2-RELEASE-sources.jar: global/hh/openapi/sdk/api/bean/hcm/HcmGetUserListResBean.java <==
package global.hh.openapi.sdk.api.bean.hcm;


/**
 * @description: 用户详细信息
 * @author: 777771
 * @date: 2023-27-27 14:27:39
 */
public class HcmGetUserListResBean {

        /**
         * 人员信息对象
         */
        private Object[] userList;

        /**
         * 当前页
         */
        private Number page;

        /**
         * 每页条数
         */
        private Number pageSize;

        /**
         * 总条数
         */
        private Number total;

        /**
         * 总页数
         */
        private Number totalPage;

    public HcmGetUserListResBean(){
    }

    public HcmGetUserListResBean(Object[] userList,Number page,Number pageSize,Number total,Number totalPage){
        this.userList=userList;
        this.page=page;
        this.pageSize=pageSize;
        this.total=total;
        this.totalPage=totalPage;
    }

    public Object[] getUserList() {
        return userList;
    }

    public void setUserList(Object[] userList) {
        this.userList = userList;
    }
    public Number getPage() {
        return page;
    }

    public void setPage(Number page) {
        this.page = page;
    }
    public Number getPageSize() {
        return pageSize;
    }

    public void setPageSize(Number pageSize) {
        this.pageSize = pageSize;
    }
    public Number getTotal() {
        return total;
    }

    public void setTotal(Number total) {
        this.total = total;
    }
    public Number getTotalPage() {
        return totalPage;
    }

    public void setTotalPage(Number totalPage) {
        this.totalPage = totalPage;
    }
}
